@@ -15,4 +15,11 @@ The following encodings are implemented:
   method). It is slower than
   :mod:`~moptipyapps.binpacking2d.encodings.ibl_encoding_1` but its results
   are never worse for any permutation and better for several.
+
+Important initial work on this code has been contributed by Mr. Rui ZHAO
+(赵睿), <zr1329142665@163.com> a Master's student at the Institute of Applied
+Optimization (应用优化研究所) of the School of
+Artificial Intelligence and Big Data (人工智能与大数据学院) at Hefei University
+(合肥大学) in Hefei, Anhui, China (中国安徽省合肥市) under the supervision of
+Prof. Dr. Thomas Weise (汤卫思教授).
 """
