@@ -85,7 +85,7 @@ from moptipyapps.binpacking2d.packing import (
     IDX_TOP_Y,
     Packing,
 )
-from moptipyapps.shared import SCOPE_INSTANCE
+from moptipyapps.utils.shared import SCOPE_INSTANCE
 
 
 @numba.njit(nogil=True, cache=True, inline="always", boundscheck=False)
