@@ -38,9 +38,9 @@ in Almost Squares' instances [6,7].
 
 Initial work on this code has been contributed by Mr. Rui ZHAO (赵睿),
 <zr1329142665@163.com> a Master's student at the Institute of Applied
-Optimization (应用优化研究所, http://iao.hfuu.edu.cn) of the School of
+Optimization (应用优化研究所) of the School of
 Artificial Intelligence and Big Data (人工智能与大数据学院) at Hefei University
-(合肥学院) in Hefei, Anhui, China (中国安徽省合肥市) under the supervision of
+(合肥大学) in Hefei, Anhui, China (中国安徽省合肥市) under the supervision of
 Prof. Dr. Thomas Weise (汤卫思教授).
 
 1. Manuel Iori, Vinícius Loti de Lima, Silvano Martello, and Michele Monaci.
@@ -304,7 +304,7 @@ def __divide_based_on_size(instances: Iterable[str],
 
 
 def _make_instance_groups(instances: Iterable[str]) \
-        -> tuple[tuple[str, str | None, tuple[str, ...]], ...]:
+        -> "tuple[tuple[str, str | None, tuple[str, ...]], ...]":
     """
     Make the standard instance groups from an instance name list.
 
@@ -462,15 +462,15 @@ def __lb_q(bin_width: int, bin_height: int, q: int, j_js: list[int]) -> int:
     sum_s3_l: int = sum(j_js[i] for i in s3_minus_s3d)
     b1 = sum_s3_l // bin_width
     if (b1 * bin_width) < sum_s3_l:
-        b1 = b1 + 1
+        b1 += 1
 
     len_s3: int = len(s3_minus_s3d)
     div: int = bin_width // ((bin_height // 2) + 1)
     b2 = len_s3 // div
     if (b2 * div) < len_s3:
-        b2 = b2 + 1
+        b2 += 1
 
-    l_tilde: Final[int] = len(s2) + (b1 if b1 >= b2 else b2)  # Equation 6.
+    l_tilde: Final[int] = len(s2) + max(b1, b2)  # Equation 6.
     bound: int = len(s1) + l_tilde
 
     # Now compute the final bound based on Theorem 3 / Equation 7.
@@ -481,8 +481,8 @@ def __lb_q(bin_width: int, bin_height: int, q: int, j_js: list[int]) -> int:
     if denom > 0:
         b = denom // bin_size
         if (b * bin_size) < denom:
-            b = b + 1
-        bound = bound + b
+            b += 1
+        bound += b
 
     return bound
 
@@ -594,7 +594,7 @@ class Instance(Component, np.ndarray):
             repetitions = check_int_range(int(repetitions), "repetitions",
                                           1, 100_000_000)
             item_area += (width * height * repetitions)
-            max_size = max(width, height)
+            max_size = max(max_size, width, height)
             if (width > min_dim) and (height > min_dim):
                 raise ValueError(
                     f"object with width={width} and height={height} does "
@@ -604,8 +604,8 @@ class Instance(Component, np.ndarray):
 
         obj: Final[Instance] = super().__new__(
             cls, use_shape, int_range_to_dtype(
-                min_value=0, max_value=max(max_dim + max_size, n_items),
-                force_signed=True))
+                min_value=0, max_value=max(
+                    max_dim + max_size + 1, n_items + 1), force_signed=True))
         for i in range(n_different_items):
             obj[i, :] = matrix[i]
 
@@ -874,7 +874,7 @@ class Instance(Component, np.ndarray):
                 _make_instance_groups(Instance.list_resources())
             setattr(obj, attr, gs)
             return gs
-        return cast(tuple[tuple[str, str | None, tuple[str, ...]], ...],
+        return cast("tuple[tuple[str, str | None, tuple[str, ...]], ...]",
                     getattr(obj, attr))
 
     @staticmethod
@@ -900,12 +900,12 @@ class Instance(Component, np.ndarray):
         container: Final = Instance.from_resource
         inst_attr: Final[str] = f"__inst_{name}"
         if hasattr(container, inst_attr):  # instance loaded?
-            return cast(Instance, getattr(container, inst_attr))
+            return cast("Instance", getattr(container, inst_attr))
         text_attr: Final[str] = f"__text_{INSTANCES_RESOURCE}"
         text: list[str]
         total_attr: Final[str] = "__total_insts"
         if hasattr(container, text_attr):  # ok, we got the text already
-            text = cast(list[str], getattr(container, text_attr))
+            text = cast("list[str]", getattr(container, text_attr))
         else:  # the first time we load the text
             with resources.files(__package__).joinpath(
                     INSTANCES_RESOURCE).open("r", encoding=UTF8) as stream:
@@ -926,7 +926,7 @@ class Instance(Component, np.ndarray):
                 instance = Instance.from_compact_str(line)
                 setattr(container, inst_attr, instance)
                 got: int = getattr(container, total_attr)
-                got = got + 1
+                got += 1
                 if got >= len(_INSTANCES):  # got all instances, can del text
                     delattr(container, total_attr)
                     delattr(container, text_attr)
