@@ -6,6 +6,7 @@ import numpy as np
 from moptipy.api.component import Component
 from moptipy.api.logging import SECTION_RESULT_Y, SECTION_SETUP
 from moptipy.evaluation.log_parser import LogParser
+from pycommons.io.path import Path
 from pycommons.types import type_error
 
 from moptipyapps.binpacking2d.instance import Instance
@@ -75,16 +76,10 @@ class Packing(Component, np.ndarray):
             we try to load it from the resources
         :returns: the Packing
         """
-        parser: Final[_PackingParser] = _PackingParser(instance)
-        parser.parse_file(file)
-        # noinspection PyProtectedMember
-        res = parser._result
-        if not isinstance(res, Packing):
-            raise type_error(res, f"packing from {file!r}", Packing)
-        return res
+        return _PackingParser(instance).parse_file(file)
 
 
-class _PackingParser(LogParser):
+class _PackingParser(LogParser[Packing]):
     """The log parser for loading packings."""
 
     def __init__(self, instance: Instance | None = None):
@@ -103,12 +98,10 @@ class _PackingParser(LogParser):
         self.__sec_mode: int = 0
         #: the packing string
         self.__packing_str: str | None = None
-        #: the result packing
-        self._result: Packing | None = None
 
-    def start_section(self, title: str) -> bool:
+    def _start_section(self, title: str) -> bool:
         """Start a section."""
-        super().start_section(title)
+        super()._start_section(title)
         self.__sec_mode = 0
         if title == SECTION_SETUP:
             if self.__instance is None:
@@ -120,7 +113,7 @@ class _PackingParser(LogParser):
             return True
         return False
 
-    def lines(self, lines: list[str]) -> bool:
+    def _lines(self, lines: list[str]) -> bool:
         """Parse the lines."""
         if self.__sec_mode == 1:
             if self.__instance is not None:
@@ -140,20 +133,20 @@ class _PackingParser(LogParser):
             raise ValueError("Should not be in section?")
         return (self.__instance is None) or (self.__packing_str is None)
 
-    def end_file(self) -> bool:
+    def _parse_file(self, file: Path) -> Packing:
         """End the file."""
+        super()._parse_file(file)
         if self.__packing_str is None:
             raise ValueError(f"Section {SECTION_RESULT_Y} missing!")
         if self.__instance is None:
             raise ValueError(f"Section {SECTION_SETUP} missing or empty!")
-        if self._result is not None:
-            raise ValueError("Applied parser to more than one log file?")
         # pylint: disable=C0415,R0401
-        from moptipyapps.binpacking2d.packing_space import (
-            PackingSpace,  # pylint: disable=C0415,R0401
+        from moptipyapps.binpacking2d.packing_space import (  # noqa: PLC0415
+            PackingSpace,  # pylint: disable=C0415,R0401  # noqa: PLC0415
         )
+        return PackingSpace(self.__instance).from_str(self.__packing_str)
 
-        self._result = PackingSpace(self.__instance)\
-            .from_str(self.__packing_str)
+    def _end_parse_file(self, file: Path) -> None:
+        """Cleanup."""
         self.__packing_str = None
-        return False
+        super()._end_parse_file(file)
