@@ -47,8 +47,8 @@ from moptipy.utils.logger import KeyValueLogSection
 from numpy.random import Generator
 from pycommons.types import type_error
 
-from moptipyapps.shared import SCOPE_INSTANCE
 from moptipyapps.tsp.instance import Instance
+from moptipyapps.utils.shared import SCOPE_INSTANCE
 
 
 @numba.njit(nogil=True, cache=True, inline="always", fastmath=False,
