@@ -69,10 +69,10 @@ So far, the following components have been implemented:
    number of such constraint violations in a game plan. If we can minimize it
    to zero, then the game plan is feasible.
 
-This is code is part of the research work of Mr. Xiang Cao (曹翔), a Master's
-student at the Institute of Applied Optimization (应用优化研究所,
-http://iao.hfuu.edu.cn) of the School of Artificial Intelligence and Big Data
-(人工智能与大数据学院) at Hefei University (合肥学院) in Hefei, Anhui, China
-(中国安徽省合肥市) under the supervision of
+This is code is part of the research work of Mr. Xiang CAO (曹翔), a Master's
+student at the Institute of Applied Optimization (应用优化研究所) of
+the School of Artificial Intelligence and Big Data
+(人工智能与大数据学院) at Hefei University (合肥大学)
+in Hefei, Anhui, China (中国安徽省合肥市) under the supervision of
 Prof. Dr. Thomas Weise (汤卫思教授).
 """
